==> anarchism_15.0.orig.tar.gz: afaq-15.0/markdown/intro.md <==
# Introduction

_"Proletarians of the world, look into the depths of your own beings, seek out
the truth and realise it yourselves: you will find it nowhere else"_  
\- Peter Arshinov  
**The History of the Makhnovist Movement**  
  
---  
  
## Welcome to our FAQ on anarchism

This FAQ was written by anarchists across the world in an attempt to present
anarchist ideas and theory to those interested in it. It is a co-operative
effort, produced by a (virtual) working group and it exists to present a
useful organising tool for anarchists on-line and, hopefully, in the real
world. It desires to present arguments on why you should be an anarchist as
well as refuting common arguments against anarchism and other proposed
solutions to the social problems we face.

As anarchist ideas seem so at odds with "common-sense" (such as "of course we
need a state and capitalism") we need to indicate **why** anarchists think
like we do. Unlike many political theories, anarchism rejects flip answers and
instead bases its ideas and ideals in an in-depth analysis of society and
humanity. In order to do both anarchism and the reader justice we have
summarised our arguments as much as possible without making them simplistic.
We know that it is a lengthy document and may put off the casual observer but
its length is unavoidable.

Readers may consider our use of extensive quoting as being an example of a
_"quotation [being] a handy thing to have about, saving one the trouble of
thinking for oneself."_ (A.A. Milne) This is not the case of course. We have
included extensive quotations by many anarchist figures for three reasons.
Firstly, to indicate that we are **not** making up our claims of what certain
anarchists thought or argued for. Secondly, and most importantly, it allows us
to link the past voices of anarchism with its present adherents. And lastly,
the quotes are used for their ability to convey ideas succinctly rather than
as an appeal to "authority."

In addition, many quotes are used in order to allow readers to investigate the
ideas of those quoted and to summarise facts and so save space. For example, a
quote by Noam Chomsky on the development of capitalism by state protection
ensures that we base our arguments on facts without having to present all the
evidence and references Chomsky uses. Similarly, we quote experts on certain
subjects (such as economics, for example) to support and bolster our analysis
and claims.

We should also indicate the history of this FAQ. It was started in 1995 when a
group of anarchists got together in order to write an FAQ refuting the claims
of certain "libertarian" capitalists to being anarchists. Those who were
involved in this project had spent many an hour on-line refuting claims by
these people that capitalism and anarchism could go together. Finally, a group
of net-activists decided the best thing was to produce an FAQ explaining why
anarchism hates capitalism and why "anarcho" capitalists are not anarchists.
However, after the suggestion of Mike Huben (who maintains the _**"Critiques
of Libertarianism"**_ web-page) it was decided that a pro-Anarchist FAQ would
be a better idea than an anti-"anarcho"-capitalist one. So the Anarchist FAQ
was born. It still bears some of the signs of its past-history. For example it
gives the likes of Ayn Rand, Murray Rothbard, and so on, far too much space
outside of Section F -- they really are not that important. However, as they
present extreme examples of everyday capitalist ideology and assumptions, they
do have their uses -- they state clearly the authoritarian implications of
capitalist ideology which its more moderate supporters try to hide or
minimise.

We think that we have produced a useful on-line resource for anarchists and
other anti-capitalists to use. Perhaps, in light of this, we should dedicate
this anarchist FAQ to the many on-line "libertarian" capitalists who, because
of their inane arguments, prompted us to start this work. Then again, that
would give them too much credit. Outside the net they are irrelevant and on
the net they are just annoying. As you may guess, sections F and G contain the
bulk of this early anti-Libertarian FAQ and are included purely to refute the
claim that an anarchist can be a supporter of capitalism that is relatively
common on the net (in the real world this would not be required as almost all
anarchists think that "anarcho"-capitalism is an oxymoron and that its
supporters are not part of the anarchist movement).

So, while coming from a very specific reason, the FAQ has expanded into more
than we originally imagined. It has become a general introduction about
anarchism, its ideas and history. Because anarchism recognises that there are
no easy answers and that freedom must be based on individual responsibility
the FAQ is quite in-depth. As it also challenges a lot of assumptions, we have
had to cover a lot of ground. We also admit that some of the "frequently asked
questions" we have included are more frequently asked than others. This is due
to the need to include relevant arguments and facts which otherwise may not
have been included.

We are sure that many anarchists will not agree 100% with what we have written
in the FAQ. That is to be expected in a movement based upon individual freedom
and critical thought. However, we are sure that most anarchists will agree
with most of what we present and respect those parts with which they do
disagree with as genuine expressions of anarchist ideas and ideals. The
anarchist movement is marked by wide-spread disagreement and argument about
various aspects of anarchist ideas and how to apply them (but also, we must
add, a wide-spread tolerance of differing viewpoints and a willingness to work
together in spite of minor disagreements). We have attempted to reflect this
in the FAQ and hope we have done a good job in presenting the ideas of all the
anarchist tendencies we discuss.

We have no desire to write in stone what anarchism is and is not. Instead the
FAQ is a starting point for people to read and learn for themselves about
anarchism and translate that learning into direct action and self-activity. By
so doing, we make anarchism a living theory, a product of individual and
social self-activity. Only by applying our ideas in practice can we find their
strengths and limitations and so develop anarchist theory in new directions
and in light of new experiences. We hope that the FAQ both reflects and aids
this process of self-activity and self-education.

We are sure that there are many issues that the FAQ does not address. If you
think of anything we could add or feel you have a question and answer which
should be included, get in contact with us. The FAQ is not our "property" but
belongs to the whole anarchist movement and so aims to be an organic, living
creation. We desire to see it grow and expand with new ideas and inputs from
as many people as possible. If you want to get involved with the FAQ then
contact us. Similarly, if others (particularly anarchists) want to distribute
all or part of it then feel free. It is a resource for the movement. For this
reason we have "copylefted" An Anarchist FAQ (see
<http://www.gnu.org/copyleft/copyleft.html> for details). By so doing we
ensure that the FAQ remains a free product, available for use by all.

One last point. Language has changed a lot over the years and this applies to
anarchist thinkers too. The use of the term "man" to refer to humanity is one
such change. Needless to say, in today's world such usage is inappropriate as
it effectively ignores half the human race. For this reason the FAQ has tried
to be gender neutral. However, this awareness is relatively recent and many
anarchists (even the female ones like Emma Goldman) used the term "man" to
refer to humanity as a whole. When we are quoting past comrades who use "man"
in this way, it obviously means humanity as a whole rather than the male sex.
Where possible, we add "woman", "women", "her" and so on but if this would
result in making the quote unreadable, we have left it as it stands. We hope
this makes our position clear.

So we hope that this FAQ entertains you and makes you think. Hopefully it will
produce a few more anarchists and speed up the creation of an anarchist
society. If all else fails, we have enjoyed ourselves creating the FAQ and
have shown anarchism to be a viable, coherent political idea.

We dedicate this work to the millions of anarchists, living and dead, who
tried and are trying to create a better world. An Anarchist FAQ was officially
released on July 19th, 1996 for that reason -- to celebrate the Spanish
Revolution of 1936 and the heroism of the Spanish anarchist movement. We hope
that our work here helps make the world a freer place.  
  
---  
  
The following self-proclaimed anarchists are (mostly) responsible for this
FAQ:

Iain McKay (main contributor and editor)  
Gary Elkin  
Dave Neal  
Ed Boraas

We would like to thank the following for their contributions and feedback:

Andrew Flood  
Mike Ballard  
Francois Coquet  
Jamal Hannah  
Mike Huben  
Greg Alt  
Chuck Munson  
Pauline McCormack  
Nestor McNab  
Kevin Carson  
Shawn Wilbur  
Nicholas Evans

and our comrades on the anarchy, oneunion and organise! mailing lists.

**_"An Anarchist FAQ"_**, **Version 1****5.0**  
Copyright (C) 1995-2014 The Anarchist FAQ Editorial Collective:  
Iain McKay, Gary Elkin, Dave Neal, Ed Boraas

Permission is granted to copy, distribute and/or modify this document under
the terms of the GNU Free Documentation License, Version 1.1 or any later
version published by the Free Software Foundation, and/or the terms of the GNU
General Public License, Version 2.0 or any later version published by the Free
Software Foundation.

See the Licenses page at <http://www.gnu.org/> for more details.

  * [An Anarchist FAQ after ten years](/afaq/10years.html)
  * [An Anarchist FAQ: Introduction to Volume 1](/afaq/vol1intro.html)
  * [An Anarchist FAQ: Introduction to Volume 2](/afaq/vol2intro.html)
  * [What Anarchists Say about An Anarchist FAQ](/afaq/quotes.html)
  * [An Anarchist FAQ Webpage Contacts](/afaq/contact.html)

[‹ What's New in the FAQ?](/afaq/new.html "Go to previous page" )
[up](/afaq/index.html "Go to parent page" ) [An Anarchist FAQ after ten years
›](/afaq/10years.html "Go to next page" )

==> anarchism_15.3.orig.tar.gz: afaq-15.3/markdown/intro.md <==
# Introduction

_"Proletarians of the world, look into the depths of your own beings, seek out
the truth and realise it yourselves: you will find it nowhere else"_  
\- Peter Arshinov  
**The History of the Makhnovist Movement**  
  
---  
  
## Welcome to our FAQ on anarchism

This FAQ was written by anarchists across the world in an attempt to present
anarchist ideas and theory to those interested in it. It is a co-operative
effort, produced by a (virtual) working group and it exists to present a
useful organising tool for anarchists on-line and, hopefully, in the real
world. It desires to present arguments on why you should be an anarchist as
well as refuting common arguments against anarchism and other proposed
solutions to the social problems we face.

As anarchist ideas seem so at odds with "common-sense" (such as "of course we
need a state and capitalism") we need to indicate **why** anarchists think
like we do. Unlike many political theories, anarchism rejects flip answers and
instead bases its ideas and ideals in an in-depth analysis of society and
humanity. In order to do both anarchism and the reader justice we have
summarised our arguments as much as possible without making them simplistic.
We know that it is a lengthy document and may put off the casual observer but
its length is unavoidable.

Readers may consider our use of extensive quoting as being an example of a
_"quotation [being] a handy thing to have about, saving one the trouble of
thinking for oneself."_ (A.A. Milne) This is not the case of course. We have
included extensive quotations by many anarchist figures for three reasons.
Firstly, to indicate that we are **not** making up our claims of what certain
anarchists thought or argued for. Secondly, and most importantly, it allows us
to link the past voices of anarchism with its present adherents. And lastly,
the quotes are used for their ability to convey ideas succinctly rather than
as an appeal to "authority."

In addition, many quotes are used in order to allow readers to investigate the
ideas of those quoted and to summarise facts and so save space. For example, a
quote by Noam Chomsky on the development of capitalism by state protection
ensures that we base our arguments on facts without having to present all the
evidence and references Chomsky uses. Similarly, we quote experts on certain
subjects (such as economics, for example) to support and bolster our analysis
and claims.

We should also indicate the history of this FAQ. It was started in 1995 when a
group of anarchists got together in order to write an FAQ refuting the claims
of certain "libertarian" capitalists to being anarchists. Those who were
involved in this project had spent many an hour on-line refuting claims by
these people that capitalism and anarchism could go together. Finally, a group
of net-activists decided the best thing was to produce an FAQ explaining why
anarchism hates capitalism and why "anarcho" capitalists are not anarchists.
However, after the suggestion of Mike Huben (who maintains the _**"Critiques
of Libertarianism"**_ web-page) it was decided that a pro-Anarchist FAQ would
be a better idea than an anti-"anarcho"-capitalist one. So the Anarchist FAQ
was born. It still bears some of the signs of its past-history. For example it
gives the likes of Ayn Rand, Murray Rothbard, and so on, far too much space
outside of Section F -- they really are not that important. However, as they
present extreme examples of everyday capitalist ideology and assumptions, they
do have their uses -- they state clearly the authoritarian implications of
capitalist ideology which its more moderate supporters try to hide or
minimise.

We think that we have produced a useful on-line resource for anarchists and
other anti-capitalists to use. Perhaps, in light of this, we should dedicate
this anarchist FAQ to the many on-line "libertarian" capitalists who, because
of their inane arguments, prompted us to start this work. Then again, that
would give them too much credit. Outside the net they are irrelevant and on
the net they are just annoying. As you may guess, sections F and G contain the
bulk of this early anti-Libertarian FAQ and are included purely to refute the
claim that an anarchist can be a supporter of capitalism that is relatively
common on the net (in the real world this would not be required as almost all
anarchists think that "anarcho"-capitalism is an oxymoron and that its
supporters are not part of the anarchist movement).

So, while coming from a very specific reason, the FAQ has expanded into more
than we originally imagined. It has become a general introduction about
anarchism, its ideas and history. Because anarchism recognises that there are
no easy answers and that freedom must be based on individual responsibility
the FAQ is quite in-depth. As it also challenges a lot of assumptions, we have
had to cover a lot of ground. We also admit that some of the "frequently asked
questions" we have included are more frequently asked than others. This is due
to the need to include relevant arguments and facts which otherwise may not
have been included.

We are sure that many anarchists will not agree 100% with what we have written
in the FAQ. That is to be expected in a movement based upon individual freedom
and critical thought. However, we are sure that most anarchists will agree
with most of what we present and respect those parts with which they do
disagree with as genuine expressions of anarchist ideas and ideals. The
anarchist movement is marked by wide-spread disagreement and argument about
various aspects of anarchist ideas and how to apply them (but also, we must
add, a wide-spread tolerance of differing viewpoints and a willingness to work
together in spite of minor disagreements). We have attempted to reflect this
in the FAQ and hope we have done a good job in presenting the ideas of all the
anarchist tendencies we discuss.

We have no desire to write in stone what anarchism is and is not. Instead the
FAQ is a starting point for people to read and learn for themselves about
anarchism and translate that learning into direct action and self-activity. By
so doing, we make anarchism a living theory, a product of individual and
social self-activity. Only by applying our ideas in practice can we find their
strengths and limitations and so develop anarchist theory in new directions
and in light of new experiences. We hope that the FAQ both reflects and aids
this process of self-activity and self-education.

We are sure that there are many issues that the FAQ does not address. If you
think of anything we could add or feel you have a question and answer which
should be included, get in contact with us. The FAQ is not our "property" but
belongs to the whole anarchist movement and so aims to be an organic, living
creation. We desire to see it grow and expand with new ideas and inputs from
as many people as possible. If you want to get involved with the FAQ then
contact us. Similarly, if others (particularly anarchists) want to distribute
all or part of it then feel free. It is a resource for the movement. For this
reason we have "copylefted" An Anarchist FAQ (see
ensure that the FAQ remains a free product, available for use by all.

One last point. Language has changed a lot over the years and this applies to
anarchist thinkers too. The use of the term "man" to refer to humanity is one
such change. Needless to say, in today's world such usage is inappropriate as
it effectively ignores half the human race. For this reason the FAQ has tried
to be gender neutral. However, this awareness is relatively recent and many
anarchists (even the female ones like Emma Goldman) used the term "man" to
refer to humanity as a whole. When we are quoting past comrades who use "man"
in this way, it obviously means humanity as a whole rather than the male sex.
Where possible, we add "woman", "women", "her" and so on but if this would
result in making the quote unreadable, we have left it as it stands. We hope
this makes our position clear.

So we hope that this FAQ entertains you and makes you think. Hopefully it will
produce a few more anarchists and speed up the creation of an anarchist
society. If all else fails, we have enjoyed ourselves creating the FAQ and
have shown anarchism to be a viable, coherent political idea.

We dedicate this work to the millions of anarchists, living and dead, who
tried and are trying to create a better world. An Anarchist FAQ was officially
released on July 19th, 1996 for that reason -- to celebrate the Spanish
Revolution of 1936 and the heroism of the Spanish anarchist movement. We hope
that our work here helps make the world a freer place.  
  
---  
  
The following self-proclaimed anarchists are (mostly) responsible for this
FAQ:

Iain McKay (main contributor and editor)  
Gary Elkin  
Dave Neal  
Ed Boraas

We would like to thank the following for their contributions and feedback:

Andrew Flood  
Mike Ballard  
Francois Coquet  
Jamal Hannah  
Mike Huben  
Greg Alt  
Chuck Munson  
Pauline McCormack  
Nestor McNab  
Kevin Carson  
Shawn Wilbur  
Nicholas Evans

and our comrades on the anarchy, oneunion and organise! mailing lists.

**_"An Anarchist FAQ"_** , **Version 1** **5.2**  
Copyright (C) 1995-2019 The Anarchist FAQ Editorial Collective:  
Iain McKay, Gary Elkin, Dave Neal, Ed Boraas

Permission is granted to copy, distribute and/or modify this document under
the terms of the GNU Free Documentation License, Version 1.1 or any later
version published by the Free Software Foundation, and/or the terms of the GNU
General Public License, Version 2.0 or any later version published by the Free
Software Foundation.


  * [An Anarchist FAQ after ten years](10years.md)
  * [An Anarchist FAQ: Introduction to Volume 1](vol1intro.md)
  * [An Anarchist FAQ: Introduction to Volume 2](vol2intro.md)
  * [What Anarchists Say about An Anarchist FAQ](quotes.md)
  * [An Anarchist FAQ Webpage Contacts](contact.md)

[‹ What's New in the FAQ?](new.md "Go to previous page") [up](index.md "Go
to parent page") [An Anarchist FAQ after ten years ›](10years.md "Go to next
page")
